@@ -556,45 +556,6 @@ def getFailedJobs():
     runGmetric('ARC_JOBS_FAILED_PER_100', num_of_jobs, 'jobs', 'int32')
 
 
-def getTransferInfo():
-    '''
-    Get the number of downloader and uploader processes.
-    Function is used if the new data staging is disabled
-    '''
-
-    try:
-    # Linux specific commands, but ganglia is only for *nix systems
-        ulp1 = subprocess.Popen(['ps', 'auxw'], stdout = subprocess.PIPE)
-        ulp2 = subprocess.Popen(['grep', 'uploader'], stdin = ulp1.stdout, stdout = subprocess.PIPE)
-        ulp1.stdout.close()
-        ulp3 = subprocess.Popen(['grep', '-v', 'grep'], stdin = ulp2.stdout, stdout = subprocess.PIPE)
-        ulp2.stdout.close()
-        ulp4 = subprocess.Popen(['wc', '-l'], stdin = ulp3.stdout, stdout = subprocess.PIPE)
-        ulp3.stdout.close()
-        ul = ulp4.stdout.readline()
-        ul = ul.strip()
-        ulp4.stdout.close()
-
-        dlp1 = subprocess.Popen(['ps', 'auxw'], stdout = subprocess.PIPE)
-        dlp2 = subprocess.Popen(['grep', 'downloader'], stdin = dlp1.stdout, stdout = subprocess.PIPE)
-        dlp1.stdout.close()
-        dlp3 = subprocess.Popen(['grep', '-v','grep'], stdin = dlp2.stdout, stdout = subprocess.PIPE)
-        dlp2.stdout.close()
-        dlp4 = subprocess.Popen(['wc', '-l'], stdin = dlp3.stdout, stdout = subprocess.PIPE)
-        dlp3.stdout.close()
-        dl = dlp4.stdout.readline()
-        dl = dl.strip()
-        dlp4.stdout.close()
-        logging.info('%s downloaders and %s uploaders running', dl, ul)
-    except OSError:
-        e = sys.exc_info()[1]
-        logging.error("Error with running OS commands: %s", str(e))
-        return
-
-    runGmetric('ARC_UPLOADING', ul, 'jobs', 'int32')
-    runGmetric('ARC_DOWNLOADING', dl, 'jobs', 'int32')
-
-
 def handler(signum, frame):
     '''
     shut down nicely
@@ -603,7 +564,6 @@ def handler(signum, frame):
     sys.exit(0)
 
 
-
 def run(conffile, pidfile, logfile):
     '''
     Main program. It creates a daemon which loops indefinitely. In each loop
@@ -650,13 +610,7 @@ def run(conffile, pidfile, logfile):
 
             if 'staging' in metrics or 'all' in metrics:
                 # data staging info
-                if 'newdatastaging' in conf['grid-manager'] and conf['grid-manager']['newdatastaging'][0] == 'no' \
-                        or 'enable_dtr' in conf['grid-manager'] and conf['grid-manager']['enable_dtr'][0] == 'no' :
-                    # monitor old downloader/uploader
-                    getTransferInfo()
-                else:
-                    # monitor DTR
-                    getDataStagingInfo()
+                getDataStagingInfo()
 
             if 'jobstates' in metrics or 'all' in metrics:
                 # jobs in different states
